***********
* Table 1 *
***********

eststo clear

foreach c in kor esp jpn {
	use data/data_`c', clear
	foreach y in frun fwin {
		eststo `y'_`c' : rdrobust `y' rv1
		quietly sum `y' if rv1 != .
		local mean_`y'_`c' = r(mean)
		local sd_`y'_`c'   = r(sd)
		
	}
}

quietly {

	capture log close
  
	log using tables/Table1.tex, text replace

	noisily display "\begin{table}[htbp]"
	noisily display "\centering"
	noisily display "\begin{threeparttable}"
	noisily display "\caption{The Effects of First Rank}"
	noisily display "\label{table_first}"
	noisily display "\begin{tabular}{lcccc}"
	noisily display "\midrule\midrule"
	noisily display "&\multicolumn{4}{c}{Dependent Variable}\\"
	noisily display "\cmidrule(r){2-5}"
	noisily display "&\multicolumn{2}{c}{Run at \$t+1\$}&\multicolumn{2}{c}{Win at \$t+1\$}\\"
	noisily display "\cmidrule(r){2-3}\cmidrule(r){4-5}"
	noisily display " & Estimate & Bandwidth & Estimate & Bandwidth\\"
	noisily display "\cmidrule(r){2-2}\cmidrule(r){3-3}\cmidrule(r){4-4}\cmidrule(r){5-5}"  
	noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}\\"
	noisily display "\midrule"

	foreach c in kor esp jpn {
		
		if "`c'" == "kor" {
			local country = "Korea"
		}
		else if "`c'" == "esp" {
			local country = "Spain"
		}
		else {
			local country = "Japan"
		}
		
		foreach y in frun fwin {
			
			estimates restore `y'_`c'
			local obs_`y'     = e(N_h_l) + e(N_h_r)
			local bw_`y'      = e(h_l) + e(h_r)
			local beta_`y'    = e(tau_cl)
			local se_`y'      = e(se_tau_cl)
			local ub_`y'      = e(tau_cl) + 1.96 * e(se_tau_cl)
			local lb_`y'      = e(tau_cl) - 1.96 * e(se_tau_cl)			
		}
		
		noisily display "\addlinespace"
		noisily display " `country' & " %5.3f `beta_frun' "&" %5.3f `bw_frun' "&" %5.3f `beta_fwin' "&" %5.3f `bw_fwin' "\\"
		noisily display " &(" %5.3f `se_frun' ")&[N=" %6.0fc `obs_frun' "]&(" %5.3f `se_fwin' ")&[N=" %6.0fc `obs_fwin'  "]\\"
		noisily display "\addlinespace"		
		noisily display "95\% CI & \multicolumn{2}{c}{[" %5.3f `lb_frun' ", " %5.3f `ub_frun'  "]}" "&\multicolumn{2}{c}{[" %5.3f `lb_fwin' ", " %5.3f `ub_fwin'  "]} \\"
		noisily display "Dep. Var. Mean&\multicolumn{2}{c}{"  %5.3f `mean_frun_`c'' "}&\multicolumn{2}{c}{" %5.3f `mean_fwin_`c'' "}\\"
		noisily display "Dep. Var. St. Dev. &\multicolumn{2}{c}{"  %5.3f `sd_frun_`c'' "}&\multicolumn{2}{c}{" %5.3f `sd_fwin_`c'' "}\\"
		noisily display "\addlinespace"

	}
	noisily display "\midrule\midrule"
	noisily display "\end{tabular}"
	noisily display "\begin{tablenotes}"
	noisily display "\footnotesize"
	noisily display "\item Standard errors in parentheses are calculated according to Calonico, Cattaneo and Titiunik (2014)."
	noisily display "The number of observations are in brackets."
	noisily display "Estimates are from local linear regressions with triangular kernel using"
	noisily display "the Calonico, Cattaneo and Titiunik (2014) (CCT) optimal bandwidth."
	noisily display "\end{tablenotes}"
	noisily display "\end{threeparttable}"
	noisily display "\end{table}"
  
	log off
  
	log close
}

***********
* Table 2 *
***********

eststo clear

foreach c in kor esp jpn {
	use data/data_`c', clear
	eststo reg_`c': areg win inc inc_firstp  if s_reg == 1, a(dist_yr_party) cluster(dist_yr)
	quietly sum win if e(sample)
	local mean_y_`c' = r(mean)
	local sd_y_`c'   = r(sd)
	
	foreach x in inc inc_firstp {
		local b_`x'_`c'  = _b[`x']
		local se_`x'_`c' = _se[`x']
		local obs_`c'    = e(N)
		local ub_`x'_`c' = _b[`x'] + 1.96 * _se[`x']
		local lb_`x'_`c' = _b[`x'] - 1.96 * _se[`x']
	}
}

quietly {

  capture log close
  
  log using tables/Table2.tex, text replace

  noisily display "\begin{table}[htbp]"
  noisily display "\centering"
  noisily display "\begin{threeparttable}"
  noisily display "\caption{The Effect of Being a First-Place vs. Non-First-Place Incumbent}"
  noisily display "\label{table_reg}"
  noisily display "\begin{tabular}{lccc}"
  noisily display "\midrule\midrule"
  noisily display "&\multicolumn{3}{c}{Dep. Var = Winning} \\"
  noisily display "\cmidrule(r){2-4}"
  noisily display "&\multicolumn{1}{c}{Korea}&\multicolumn{1}{c}{Spain}&\multicolumn{1}{c}{Japan}\\"
  noisily display "\cmidrule(r){2-2}\cmidrule(r){3-3}\cmidrule(r){4-4}"
  noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}\\"
  noisily display "\midrule"

  noisily display "\addlinespace"
  noisily display " First-Place &"  %5.3f `b_inc_firstp_kor'   "&" %5.3f `b_inc_firstp_esp' "&" %5.3f `b_inc_firstp_jpn' "" "\\"
  noisily display "  &("             %5.3f `se_inc_firstp_kor' ")&(" %5.3f `se_inc_firstp_esp' ")&(" %5.3f `se_inc_firstp_jpn' ")\\"
  noisily display "  &["  %5.3f `lb_inc_firstp_kor' "," %5.3f `ub_inc_firstp_kor' "]&" "["  %5.3f `lb_inc_firstp_esp' "," %5.3f `ub_inc_firstp_esp' "]&" "["  %5.3f `lb_inc_firstp_jpn' "," %5.3f `ub_inc_firstp_jpn' "]\\"  
  noisily display "\addlinespace"

  noisily display "\addlinespace"
  noisily display " Incumbent &"  %5.3f `b_inc_kor'   "&" %5.3f `b_inc_esp' "&" %5.3f `b_inc_jpn' "\\"
  noisily display " &("             %5.3f `se_inc_kor' ")&(" %5.3f `se_inc_esp' ")&(" %5.3f `se_inc_jpn' ")\\"
  noisily display "  &["  %5.3f `lb_inc_kor' "," %5.3f `ub_inc_kor' "]&" "["  %5.3f `lb_inc_esp' "," %5.3f `ub_inc_esp' "]&" "["  %5.3f `lb_inc_jpn' "," %5.3f `ub_inc_jpn' "]\\"  
  noisily display "\addlinespace"  

   
  noisily display "\midrule"
  noisily display "\addlinespace"
  noisily display "Dep. Var. Mean   & " "" %5.3f `mean_y_kor' "&" %5.3f `mean_y_esp' "&" %5.3f `mean_y_jpn' "\\"
  noisily display "Dep. Var. St. Dev.   & " "" %5.3f `sd_y_kor' "&" %5.3f `sd_y_esp' "&" %5.3f `sd_y_jpn' "\\"
  noisily display "Obs.   & " "" %6.0fc `obs_kor' "&" %6.0fc `obs_esp' "&" %6.0fc `obs_jpn' "\\"

  noisily display "\midrule\midrule"
  noisily display "\end{tabular}"
  noisily display "\begin{tablenotes}"
  noisily display "\footnotesize"
  noisily display "\item Standard errors, clustered at the district $\times$ year level, are in parentheses."
  noisily display "District $\times$ party $\times$ year fixed effects are included in all columns."
  noisily display "The 95\% confidence intervals are in square brackets."
  noisily display "\end{tablenotes}"
  noisily display "\end{threeparttable}"
  noisily display "\end{table}"
  
  log off
  
  log close
}

***********
* Table 3 *
***********

use data/data_kor, clear

eststo clear

local controls "age20_30 age60 female"

foreach y in fst party_money {

	eststo: areg `y' inc inc_firstp `controls' if year >= 2010 & ind == 0, a(dist_yr_party) cluster(dist_yr)
	local `y'_b_inc         = _b[inc]
	local `y'_b_inc_firstp  = _b[inc_firstp]
	local `y'_se_inc        = _se[inc]
	local `y'_se_inc_firstp = _se[inc_firstp]
	local `y'_ub_inc        = _b[inc] + 1.96 * _se[inc]
	local `y'_lb_inc        = _b[inc] - 1.96 * _se[inc]
	local `y'_ub_inc_firstp = _b[inc_firstp] + 1.96 * _se[inc_firstp]
	local `y'_lb_inc_firstp = _b[inc_firstp] - 1.96 * _se[inc_firstp]	
	
	local `y'_obs = e(N)
	quietly sum `y' if e(sample)
	local mean_`y' = r(mean)
	local sd_`y' = r(sd)
}

quietly {

  capture log close
  
  log using tables/Table3.tex, text replace

  noisily display "\begin{table}[htbp]"
  noisily display "\centering"
  noisily display "\begin{threeparttable}"
  noisily display "\caption{The Incumbency, First Rank, and Party Support (Korea)}"
  noisily display "\label{table_reg_party}"
  noisily display "\begin{tabular}{lcc}"
  noisily display "\midrule\midrule"
  noisily display "&\multicolumn{2}{c}{Dep. Var} \\"
  noisily display "\cmidrule(r){2-3}"
  noisily display " &\multicolumn{1}{c}{First on} &\multicolumn{1}{c}{Party}\\"
  noisily display " &\multicolumn{1}{c}{Ballot} &\multicolumn{1}{c}{Money}\\"
  noisily display "\cmidrule(r){2-2}\cmidrule(r){3-3}"
  noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}\\"
  noisily display "\midrule"

  noisily display "\addlinespace"
  noisily display " First-Place &"  %5.3f `fst_b_inc_firstp'  "&" %5.3f `party_money_b_inc_firstp' "\\"
  noisily display "  &("             %5.3f `fst_se_inc_firstp' ")"  "&(" %5.3f `party_money_se_inc_firstp' ")\\"
  noisily display "  &["  %5.3f `fst_lb_inc_firstp' "," %5.3f `fst_ub_inc_firstp' "]&" "["  %5.3f `party_money_lb_inc_firstp' "," %5.3f `party_money_ub_inc_firstp' "]\\"  
  
  
  noisily display "\addlinespace"

  noisily display "\addlinespace"
  noisily display " Incumbent &"  %5.3f `fst_b_inc' "&" %5.3f `party_money_b_inc' "\\"
  noisily display "  &("             %5.3f `fst_se_inc' ")&(" %5.3f `party_money_se_inc' ")\\"
  noisily display "  &["  %5.3f `fst_lb_inc' "," %5.3f `fst_ub_inc' "]&" "["  %5.3f `party_money_lb_inc' "," %5.3f `party_money_ub_inc' "]\\"  
  
  noisily display "\addlinespace"  
      
  noisily display "\midrule"
  noisily display "\addlinespace"
  noisily display "Dep. Var. Mean   & "  %5.3f `mean_fst' "&" %5.3f `mean_party_money'  "\\"
  noisily display "Dep. Var. St. Dev.   & "  %5.3f `sd_fst' "&" %5.3f `sd_party_money'  "\\"
  noisily display "Obs.   & "  %6.0fc `fst_obs' "&"  %6.0fc `party_money_obs'  "\\"

  noisily display "\midrule\midrule"
  noisily display "\end{tabular}"
  noisily display "\begin{tablenotes}"
  noisily display "\footnotesize"
  noisily display "\item Standard errors, clustered at the district $\times$ year level, are in parentheses."
  noisily display "District $\times$ party $\times$ year fixed effects are included in all columns."
  noisily display "The control variables included in the regressions are: dummy variables for different age groups and female."
  noisily display "The 95\% confidence intervals are in square brackets."
  noisily display "\end{tablenotes}"
  noisily display "\end{threeparttable}"
  noisily display "\end{table}"
  
  log off
  
  log close
}

***********
* Table 4 *
***********

use data/data_kor, clear

eststo clear
foreach x in frun_high fwin_high {
	eststo inc_`x' : rdrobust `x' rv
	quietly sum `x' if rv != .
	local mean_`x'_inc = r(mean)
	local sd_`x'_inc   = r(sd)
	eststo fsp_`x' : rdrobust `x' rv1
	quietly sum `x' if rv1 != .
	local mean_`x'_first = r(mean)
	local sd_`x'_first   = r(sd)
}

quietly {

	capture log close
  
    log using tables/Table4.tex, text replace

	noisily display "\begin{table}[htbp]"
	noisily display "\centering"
	noisily display "\begin{threeparttable}"
	noisily display "\caption{The Effects of Incumbency and First Rank on Running for and Winning Higher Office (Korea)}"
	noisily display "\label{table_high}"
	noisily display "\begin{tabular}{lcccc}"
	noisily display "\midrule\midrule"
	noisily display "&\multicolumn{2}{c}{Incumbency}&\multicolumn{2}{c}{First Rank}\\"
	noisily display "\cmidrule(r){2-3}\cmidrule(r){4-5}"
	noisily display " & Estimate & Bandwidth & Estimate & Bandwidth\\"
	noisily display "\cmidrule(r){2-2}\cmidrule(r){3-3}\cmidrule(r){4-4}\cmidrule(r){5-5}"  
	noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}\\"
	noisily display "\midrule"
  

	foreach x in frun_high fwin_high {
		
		foreach y in inc fsp {
			estimates restore `y'_`x'
			local obs_`y'     = e(N_h_l) + e(N_h_r)
			local bw_`y'      = e(h_l) + e(h_r)
			local beta_`y'    = e(tau_cl)
			local se_`y'      = e(se_tau_cl)
			local ub_`y'      = e(tau_cl) + 1.96 * e(se_tau_cl)
			local lb_`y'      = e(tau_cl) - 1.96 * e(se_tau_cl)			
		}
		local varname : variable label `x'
		
		noisily display "\addlinespace"
		noisily display " `varname' & " %5.3f `beta_inc' "&" %5.3f `bw_inc' "&" %5.3f `beta_fsp' "&" %5.3f `bw_fsp' "\\"
		noisily display " &(" %5.3f `se_inc' ")&[N=" %6.0fc `obs_inc' "]&(" %5.3f `se_fsp' ")&[N=" %6.0fc `obs_fsp'  "]\\"
		noisily display "\addlinespace"		
		noisily display "95\% CI & \multicolumn{2}{c}{[" %5.3f `lb_inc' ", " %5.3f `ub_inc'  "]}" "&\multicolumn{2}{c}{[" %5.3f `lb_fsp' ", " %5.3f `ub_fsp'  "]} \\"
		noisily display "Dep. Var. Mean &\multicolumn{2}{c}{"  %5.3f `mean_`x'_inc' "}&\multicolumn{2}{c}{" %5.3f `mean_`x'_first' "}\\"
		noisily display "Dep. Var. St. Dev. &\multicolumn{2}{c}{"  %5.3f `sd_`x'_inc' "}&\multicolumn{2}{c}{" %5.3f `sd_`x'_first' "}\\"
		noisily display "\addlinespace"
	}

	noisily display "\midrule\midrule"
	noisily display "\end{tabular}"
	noisily display "\begin{tablenotes}"
	noisily display "\footnotesize"
	noisily display "\item Standard errors in parentheses are calculated according to Calonico, Cattaneo and Titiunik (2014). The number of observations are in brackets."
	noisily display "Estimates are from local linear regressions with triangular kernel using"
	noisily display "the Calonico, Cattaneo and Titiunik (2014) (CCT) optimal bandwidth."
	noisily display "\end{tablenotes}"
	noisily display "\end{threeparttable}"
	noisily display "\end{table}"
  
	log off
  
	log close
}

***********
* Table 5 *
***********

use data/data_kor_pleg, clear

eststo clear

local controls "age20_30 age60 female"

quietly reg win win_mc inc vspr age20_30 age60 female
gen s = e(sample)

egen sd_yr_party = group(year sido party)

quietly reghdfe win win_mc firstp_mc inc age20_30 age60 female, a(dist_yr sd_yr_party) cluster(dist_yr)
local b_win_mc     = _b[win_mc]
local se_win_mc    = _se[win_mc]
local ub_win_mc    = _b[win_mc] + 1.96 * _se[win_mc]
local lb_win_mc    = _b[win_mc] - 1.96 * _se[win_mc]
local b_firstp_mc  = _b[firstp_mc]
local se_firstp_mc = _se[firstp_mc]
local ub_firstp_mc = _b[firstp_mc] + 1.96 * _se[firstp_mc]
local lb_firstp_mc = _b[firstp_mc] - 1.96 * _se[firstp_mc]
local b_inc2  = _b[inc]
local se_inc2 = _se[inc]
local ub_inc2 = _b[inc] + 1.96 * _se[inc]
local lb_inc2 = _b[inc] - 1.96 * _se[inc]

quietly reghdfe win win_mc firstp_mc inc vspr age20_30 age60 female, a(dist_yr sd_yr_party) cluster(dist_yr)
local b_win_mc_nv  = _b[win_mc]
local se_win_mc_nv = _se[win_mc]
local lb_win_mc_nv = _b[win_mc] - 1.96 * _se[win_mc]
local ub_win_mc_nv = _b[win_mc] + 1.96 * _se[win_mc]
local b_firstp_mc_nv  = _b[firstp_mc]
local se_firstp_mc_nv = _se[firstp_mc]
local lb_firstp_mc_nv = _b[firstp_mc] - 1.96 * _se[firstp_mc]
local ub_firstp_mc_nv = _b[firstp_mc] + 1.96 * _se[firstp_mc]
local b_inc2_nv  = _b[inc]
local se_inc2_nv = _se[inc]
local ub_inc2_nv = _b[inc] + 1.96 * _se[inc]
local lb_inc2_nv = _b[inc] - 1.96 * _se[inc]

local obs = e(N)
quietly sum win if e(sample)
local mean_dep = r(mean)
local sd_dep   = r(sd)

quietly {

  capture log close
  
  log using tables/Table5.tex, text replace

  noisily display "\begin{table}[htbp]"
  noisily display "\centering"
  noisily display "\begin{threeparttable}"
  noisily display "\caption{The Effect of Serving a Term in a Lower-Tier Legislature on Winning a Seat in the Upper-Tier Legislative Election (Korea)}"
  noisily display "\label{table_reg_pleg}"
  noisily display "\begin{tabular}{lcc}"
  noisily display "\midrule\midrule"
  noisily display "&\multicolumn{2}{c}{Dep. Var = } \\"
  noisily display "&\multicolumn{2}{c}{Winning Upper Office} \\"
  noisily display "\cmidrule(r){2-3}"
  noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}\\"
  noisily display "\midrule"

  noisily display "\addlinespace"
  noisily display "Incumbent &" %5.3f `b_inc2'   "&" %5.3f `b_inc2_nv' "\\"
  noisily display "  &("           %5.3f `se_inc2' ")&("    %5.3f `se_inc2_nv' ")\\"
  noisily display "  &["  %5.3f `lb_inc2' "," %5.3f `ub_inc2' "]&" "["  %5.3f `lb_inc2_nv' "," %5.3f `ub_inc2_nv' "]\\"  
  
  noisily display "\addlinespace"
  noisily display " Winner of &"    %5.3f `b_win_mc'  "&"  %5.3f `b_win_mc_nv'  "\\"
  noisily display " Lower Office &("   %5.3f `se_win_mc' ")"   "&("   %5.3f `se_win_mc_nv' ")"  "\\"
  noisily display "  &["  %5.3f `lb_win_mc' "," %5.3f `ub_win_mc' "]&" "["  %5.3f `lb_win_mc_nv' "," %5.3f `ub_win_mc_nv' "]\\"  
  
  noisily display "\addlinespace"  
  
  noisily display " First-Place  &"  %5.3f `b_firstp_mc' "&" %5.3f `b_firstp_mc_nv' "\\"
  noisily display " Winner of" "&(" %5.3f `se_firstp_mc' ")&("  %5.3f `se_firstp_mc_nv' ")\\"
  noisily display " Lower Office &["  %5.3f `lb_firstp_mc' "," %5.3f `ub_firstp_mc' "]&" "["  %5.3f `lb_firstp_mc_nv' "," %5.3f `ub_firstp_mc_nv' "]\\"  
  
  noisily display "\addlinespace"
  
  noisily display "\midrule"
  noisily display "\addlinespace"
  noisily display "Dep. Var. Mean &\multicolumn{2}{c}{"  %5.3f `mean_dep' "}\\"
  noisily display "Dep. Var. St. Dev. &\multicolumn{2}{c}{"  %5.3f `sd_dep' "}\\"
  noisily display "Obs.   & "  %6.0fc `obs'  "&"  %6.0fc `obs' "\\"
  noisily display "Control the Normal Vote & No  & Yes \\" 

  noisily display "\midrule\midrule"
  noisily display "\end{tabular}"
  noisily display "\begin{tablenotes}"
  noisily display "\footnotesize"
  noisily display "\item Standard errors, clustered at the district $\times$ year level, are in parentheses."
  noisily display "Province $\times$ party $\times$ year fixed effects are included in all columns."
  noisily display "The normal vote is defined as each party's vote share in the ""
  noisily display "proportional representation tier of the provincial legislative election."
  noisily display "Dummy variables for different age groups and female are also included"
  noisily display "as control variables."
  noisily display "The 95\% confidence intervals are in square brackets."  
  noisily display "\end{tablenotes}"
  noisily display "\end{threeparttable}"
  noisily display "\end{table}"
  
  log off
  
  log close
}


************
* Table A1 *
************

use data/data_kor, clear

local vars "win firstp secondp vs frun fwin frun_high fwin_high fst party_money"

label var win         "Win at \$t\$"
label var firstp      "First-Place"
label var secondp     "Second-Place"
label var frun        "Run at \$t+1\$"
label var fwin        "Win at \$t+1\$"
label var frun_high   "Run for Higher Office at \$t+1\$"
label var fwin_high   "Win Higher Office at \$t+1\$"
label var fst         "Being Place First the Ballot"
label var party_money "Share of Party Money"
label var rv          "Running Variable (incumbency)"
label var rv1         "Running Variable (first-place)"
label var rv2         "Running Variable (second-place)"
label var vs          "Candidate Vote Share"

eststo clear
eststo: quietly estpost sum `vars' if frun != .

esttab using tables/table_sum_tmp_kor.tex,  ///
  replace label cells("mean(fmt(%5.3f)) sd min max count(fmt(%6.0fc))") ///
  noobs booktabs nomtitles fragment nonumbers alignment(rrrcc) ///
  collabels("{Mean}" "{Std Dev}" "{Min}" "{Max}" "{N}")


use data/data_esp, clear

label var win         "Win at \$t\$"
label var fwin        "Win at \$t+1$"
label var frun        "Run at \$t+1$"
label var firstp      "First-Place"
label var secondp     "Second-Place"
label var vs          "Candidate Vote Share"

local vars_esp "win firstp secondp vs2 frun fwin"
 
eststo clear
eststo: quietly estpost sum `vars_esp' if frun != .

esttab using tables/table_sum_tmp_esp.tex,  ///
  replace label cells("mean(fmt(%5.3f)) sd min max count(fmt(%6.0fc))") ///
  noobs booktabs nomtitles fragment nonumbers alignment(rrrcc) ///
  collabels("{Mean}" "{Std Dev}" "{Min}" "{Max}" "{N}")
  

use data/data_jpn, clear
 
local vars_jpn "win firstp secondp vs frun fwin"

label var win         "Win at \$t\$"
label var fwin        "Win at \$t+1$"
label var frun        "Run at \$t+1$"
label var vs          "Candidate Vote Share"

eststo clear
eststo: quietly estpost sum `vars_jpn' if frun != .

esttab using tables/table_sum_tmp_jpn.tex,  ///
  replace label cells("mean(fmt(%5.3f)) sd min max count(fmt(%6.0fc))") ///
  noobs booktabs nomtitles fragment nonumbers alignment(rrrcc) ///
  collabels("{Mean}" "{Std Dev}" "{Min}" "{Max}" "{N}")

  
use data/data_kor_pleg, clear

quietly areg win nfirstp_mc firstp_mc inc age20_30 age60 female, a(dist_yr) cluster(dist_yr)
keep if e(sample)

local vars_pleg "win firstp_mc nfirstp_mc vs inc"  
 
label var win          "Win at \$t\$"
label var firstp_mc    "First-Place Winner (Lower Office) at \$t-1\$"
label var nfirstp_mc   "Non-First-Place Winner (Lower Office) at \$t-1\$"
label var vs           "Candidate Vote Share"
label var inc		   "Incumbent"

eststo clear
eststo: quietly estpost sum `vars_pleg'

esttab using tables/table_sum_tmp_pleg.tex,  ///
  replace label cells("mean(fmt(%5.3f)) sd min max count(fmt(%6.0fc))") ///
  noobs booktabs nomtitles fragment nonumbers alignment(rrrcc) ///
  collabels("{Mean}" "{Std Dev}" "{Min}" "{Max}" "{N}")


quietly {

	capture log close
  
	log using tables/TableA1.tex, text replace

	noisily display "\begin{table}[htbp]\centering"
	noisily display "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}"
	noisily display "\caption{Summary Statistics} \label{table_sum}"
	noisily display "\begin{tabular}{l*{4}{S}c}"
	noisily display "\midrule\midrule"
	noisily display "\multicolumn{6}{c}{\textit{Panel A: Korean Municipal Legislative Election}}\\"
	noisily display "\addlinespace"
	noisily display "\input{table_sum_tmp_kor.tex}"
	noisily display "\midrule"
	noisily display "\addlinespace"
	
	noisily display "\multicolumn{6}{c}{\textit{Panel B: Spanish Senatorial Election}}\\"
	noisily display "\addlinespace"	
	noisily display "\input{table_sum_tmp_esp.tex}"	
	noisily display "\midrule"
	noisily display "\addlinespace"
	
	noisily display "\multicolumn{6}{c}{\textit{Panel C: Japanese House of Representative Election}}\\"
	noisily display "\addlinespace"	
	noisily display "\input{table_sum_tmp_jpn.tex}"
	noisily display "\midrule"
	noisily display "\addlinespace"	
	
	noisily display "\multicolumn{6}{c}{\textit{Panel D: Korean Provincial Legislative Election}}\\"
	noisily display "\addlinespace"	
	noisily display "\input{table_sum_tmp_pleg.tex}"	
	noisily display "\midrule\midrule"
	noisily display "\end{tabular}"
	noisily display "\end{table}"
  
	log off

	log close
  
}


************
* Table B1 *
************


eststo clear

foreach c in kor esp jpn {
	use data/data_`c', clear
	foreach y in frun fwin {
		eststo `y'_`c' : rdrobust `y' rv
		quietly sum `y' if rv != .
		local mean_`y'_`c' = r(mean)		
		local sd_`y'_`c' = r(sd)		
	}
}

quietly {

	capture log close
  
	log using tables/TableB1.tex, text replace

	noisily display "\begin{table}[htbp]"
	noisily display "\centering"
	noisily display "\begin{threeparttable}"
	noisily display "\caption{The Effects of Incumbency}"
	noisily display "\label{table_inc}"
	noisily display "\begin{tabular}{lcccc}"
	noisily display "\midrule\midrule"
	noisily display "&\multicolumn{4}{c}{Dependent Variable}\\"
	noisily display "\cmidrule(r){2-5}"
	noisily display "&\multicolumn{2}{c}{Run at \$t+1\$}&\multicolumn{2}{c}{Win at \$t+1\$}\\"
	noisily display "\cmidrule(r){2-3}\cmidrule(r){4-5}"
	noisily display " & Estimate & Bandwidth & Estimate & Bandwidth\\"
	noisily display "\cmidrule(r){2-2}\cmidrule(r){3-3}\cmidrule(r){4-4}\cmidrule(r){5-5}"  
	noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}\\"
	noisily display "\midrule"

	foreach c in kor esp jpn {
		
		if "`c'" == "kor" {
			local country = "Korea"
		}
		else if "`c'" == "esp" {
			local country = "Spain"
		}
		else {
			local country = "Japan"
		}
		
		foreach y in frun fwin {
			
			estimates restore `y'_`c'
			local obs_`y'     = e(N_h_l) + e(N_h_r)
			local bw_`y'      = e(h_l) + e(h_r)
			local beta_`y'    = e(tau_cl)
			local se_`y'      = e(se_tau_cl)
			local ub_`y'      = e(tau_cl) + 1.96 * e(se_tau_cl)
			local lb_`y'      = e(tau_cl) - 1.96 * e(se_tau_cl)			
		}
		
		noisily display "\addlinespace"
		noisily display " `country' & " %5.3f `beta_frun' "&" %5.3f `bw_frun' "&" %5.3f `beta_fwin' "&" %5.3f `bw_fwin' "\\"
		noisily display " &(" %5.3f `se_frun' ")&[N=" %6.0fc `obs_frun' "]&(" %5.3f `se_fwin' ")&[N=" %6.0fc `obs_fwin'  "]\\"
		noisily display "\addlinespace"		
		noisily display "95\% CI & \multicolumn{2}{c}{[" %5.3f `lb_frun' ", " %5.3f `ub_frun'  "]}" "&\multicolumn{2}{c}{[" %5.3f `lb_fwin' ", " %5.3f `ub_fwin'  "]} \\"
		noisily display "Dep. Var. Mean &\multicolumn{2}{c}{"  %5.3f `mean_frun_`c'' "}&\multicolumn{2}{c}{" %5.3f `mean_fwin_`c'' "}\\"
		noisily display "Dep. Var.St. Dev. &\multicolumn{2}{c}{"  %5.3f `sd_frun_`c'' "}&\multicolumn{2}{c}{" %5.3f `sd_fwin_`c'' "}\\"
		noisily display "\addlinespace"

	}

	noisily display "\midrule\midrule"
	noisily display "\end{tabular}"
	noisily display "\begin{tablenotes}"
	noisily display "\footnotesize"
	noisily display "\item Standard errors in parentheses are calculated according to Calonico, Cattaneo and Titiunik (2014)."
	noisily display "The number of observations are in brackets."
	noisily display "Estimates are from local linear regressions with triangular kernel using"
	noisily display "the Calonico, Cattaneo and Titiunik (2014) (CCT) optimal bandwidth."
	noisily display "\end{tablenotes}"
	noisily display "\end{threeparttable}"
	noisily display "\end{table}"
  
	log off
  
	log close
}


************
* Table C1 *
************

use data/data_kor, clear

label var inc_firstp "First-Place Winner at {c $|}t-1$"

eststo clear
foreach x in inc l_run inc_firstp age20_30 age60 female major {
	eststo `x'1 : rdrobust `x' rv  if year != 2018
	eststo `x'2:  rdrobust `x' rv1 if year != 2018 
}

quietly {

	capture log close
  
	log using tables/TableC1.tex, text replace

	noisily display "\begin{table}[htbp]"
	noisily display "\centering"
	noisily display "\begin{threeparttable}"
	noisily display "\caption{Placebo Tests (Korea)}"
	noisily display "\label{table_placebo_kor}"
	noisily display "\begin{tabular}{lcccc}"
	noisily display "\midrule\midrule"
	noisily display "&\multicolumn{4}{c}{Running Variable =}\\"
	noisily display "\cmidrule(r){2-5}" 
	noisily display "&\multicolumn{2}{c}{Vote Margin Between}&\multicolumn{2}{c}{Vote Margin Between}\\"
	noisily display "&\multicolumn{2}{c}{Winner vs. Loser}&\multicolumn{2}{c}{First vs. Second-Place}\\"
	noisily display "&\multicolumn{2}{c}{}&\multicolumn{2}{c}{Candidates}\\"
	noisily display "\cmidrule(r){2-3}\cmidrule(r){4-5}  " 
	noisily display " & Estimate & Bandwidth & Estimate & Bandwidth \\"
	noisily display "\cmidrule(r){2-2}\cmidrule(r){3-3}\cmidrule(r){4-4}\cmidrule(r){5-5}  "
	noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}\\"
	noisily display "\midrule"

	foreach x in l_run inc inc_firstp age20_30 age60 female major {
		forvalues i = 1/2 {
			estimates restore `x'`i'
			local obs`i'     = e(N_h_l) + e(N_h_r)
			local bw`i'      = e(h_l) + e(h_r)
			local beta`i'    = e(tau_cl)
			local se`i'      = e(se_tau_cl)
			local varname : variable label `x'
		}
	
		noisily display "\addlinespace"
		noisily display " `varname' &"  %5.3f `beta1' "&" %5.3f `bw1' "&" %5.3f `beta2' "&" %5.3f `bw2' "\\"
		noisily display " &(" %5.3f `se1' ")&[N="  %10.0gc `obs1' "]&(" %5.3f `se2' ")&[N="  %10.0gc `obs2' "]\\"
		noisily display "\addlinespace"
	
	}


	noisily display "\midrule\midrule"
	noisily display "\end{tabular}"
	noisily display "\begin{tablenotes}"
	noisily display "\footnotesize"
	noisily display "\item Standard errors in parentheses are calculated according to Calonico, Cattaneo and Titiunik (2014). The number of observations are in brackets."
	noisily display "Estimates are from local linear regressions with triangular kernel using"
	noisily display "the Calonico, Cattaneo and Titiunik (2014) (CCT) optimal bandwidth."
	noisily display "\end{tablenotes}"
	noisily display "\end{threeparttable}"
	noisily display "\end{table}"
  
	log off
  
	log close
}


************
* Table C2 *
************

eststo clear
foreach y in esp jpn {
	use data/data_`y', clear
	capture rename l_run lrun
	capture rename l_win lwin
	capture rename inc   lwin
	capture rename inc_firstp lfirstp
	
	foreach x in lrun lwin lfirstp female {
		eststo `x'1`y' :  rdrobust `x' rv
		eststo `x'2`y' :  rdrobust `x' rv1
	}
}

label var lrun    "Run at {c $|}t-1$"
label var lwin    "Win at {c $|}t-1$"
label var lfirstp "First-Place Winner at {c $|}t-1$"
label var female  "Female"

quietly {

	capture log close
  
	log using tables/TableC2.tex, text replace

	noisily display "\begin{table}[htbp]"
	noisily display "\centering"
	noisily display "\begin{threeparttable}"
	noisily display "\caption{Placebo Tests (Spain and Japan)}"
	noisily display "\label{table_placebo_others}"
	noisily display "\begin{tabular}{lcccc}"
	noisily display "\midrule\midrule"
	noisily display "&\multicolumn{4}{c}{Running Variable =}\\"
	noisily display "\cmidrule(r){2-5}" 
	noisily display "&\multicolumn{2}{c}{Vote Margin Between}&\multicolumn{2}{c}{Vote Margin Between}\\"
	noisily display "&\multicolumn{2}{c}{Winner vs. Loser}&\multicolumn{2}{c}{First vs. Second-Place}\\"
	noisily display "&\multicolumn{2}{c}{}&\multicolumn{2}{c}{Candidates}\\"
	noisily display "\cmidrule(r){2-3}\cmidrule(r){4-5}  " 
	noisily display " & Estimate & Bandwidth & Estimate & Bandwidth \\"
	noisily display "\cmidrule(r){2-2}\cmidrule(r){3-3}\cmidrule(r){4-4}\cmidrule(r){5-5}  "
	noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}\\"
	noisily display "\midrule"

	noisily display "\multicolumn{5}{l}{\textit{Panel A: Spain}}\\"	
	
	foreach x in lrun lwin lfirstp female {
		forvalues i = 1/2 {
			estimates restore `x'`i'esp
			local obs`i'     = e(N_h_l) + e(N_h_r)
			local bw`i'      = e(h_l) + e(h_r)
			local beta`i'    = e(tau_cl)
			local se`i'      = e(se_tau_cl)
			local varname : variable label `x'
		}
	
		noisily display "\addlinespace"
		noisily display " `varname' &"  %5.3f `beta1' "&" %5.3f `bw1' "&" %5.3f `beta2' "&" %5.3f `bw2' "\\"
		noisily display " &(" %5.3f `se1' ")&[N="  %10.0gc `obs1' "]&(" %5.3f `se2' ")&[N="  %10.0gc `obs2' "]\\"
	
	
	}

	noisily display "\addlinespace"
	noisily display "\multicolumn{5}{l}{\textit{Panel B: Japan}}\\"	
	
	foreach x in lrun lwin lfirstp female {
		forvalues i = 1/2 {
			estimates restore `x'`i'jpn
			local obs`i'     = e(N_h_l) + e(N_h_r)
			local bw`i'      = e(h_l) + e(h_r)
			local beta`i'    = e(tau_cl)
			local se`i'      = e(se_tau_cl)
			local varname : variable label `x'
		}
	
		noisily display "\addlinespace"
		noisily display " `varname' &"  %5.3f `beta1' "&" %5.3f `bw1' "&" %5.3f `beta2' "&" %5.3f `bw2' "\\"
		noisily display " &(" %5.3f `se1' ")&[N="  %10.0gc `obs1' "]&(" %5.3f `se2' ")&[N="  %10.0gc `obs2' "]\\"
	
	
	}
	noisily display "\midrule\midrule"
	noisily display "\end{tabular}"
	noisily display "\begin{tablenotes}"
	noisily display "\footnotesize"
	noisily display "\item Standard errors in parentheses are calculated according to Calonico, Cattaneo and Titiunik (2014). The number of observations are in brackets."
	noisily display "Estimates are from local linear regressions with triangular kernel using"
	noisily display "the Calonico, Cattaneo and Titiunik (2014) (CCT) optimal bandwidth."
	noisily display "\end{tablenotes}"
	noisily display "\end{threeparttable}"
	noisily display "\end{table}"
  
	log off
  
	log close
}


************
* Table D1 *
************

eststo clear
	
foreach c in esp jpn {
	use data/data_`c', clear

	gen treat1 = (rv1 > 0) if rv1 != .
	gen treat  = (rv > 0 ) if rv  != .
	rdbound frun fwin treat rv
	foreach x in b_ub b_lb se_ub se_lb {
		local `x'_inc_`c' = e(`x')
	}
	rdbound frun fwin treat1 rv1
	foreach x in b_ub b_lb se_ub se_lb {
		local `x'_fsp_`c' = e(`x')
	}	
}

quietly {

	capture log close
  
	log using tables/TableD1.tex, text replace

	noisily display "\begin{table}[htbp]"
	noisily display "\centering"
	noisily display "\begin{threeparttable}"
	noisily display "\caption{Bounds on The Conditional Effects of Incumbency and First Rank}"
	noisily display "\label{table_bound}"
	noisily display "\begin{tabular}{lcccc}"
	noisily display "\midrule\midrule"
	noisily display "&\multicolumn{2}{c}{Incumbency}&\multicolumn{2}{c}{First Rank}\\"
	noisily display "\cmidrule(r){2-3}\cmidrule(r){4-5}"
	noisily display " & Lower Bound & Upper Bound & Lower Bound & Upper Bound\\"
	noisily display "\cmidrule(r){2-2}\cmidrule(r){3-3}\cmidrule(r){4-4}\cmidrule(r){5-5}"  
	noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}\\"
	noisily display "\midrule"

	noisily display "\addlinespace"
	noisily display " Spain & " %5.3f `b_lb_inc_esp' "&" %5.3f `b_ub_inc_esp' "&" %5.3f `b_ub_fsp_esp' "&" %5.3f `b_lb_fsp_esp' "\\"
	noisily display " &(" %5.3f `se_lb_inc_esp' ")&(" %5.3f `se_ub_inc_esp' ")&(" %5.3f `se_ub_fsp_esp' ")&(" %5.3f `se_lb_fsp_esp'  ")\\"

	noisily display "\addlinespace"
	noisily display " Japan & " %5.3f `b_lb_inc_jpn' "&" %5.3f `b_ub_inc_jpn' "&" %5.3f `b_lb_fsp_jpn' "&" %5.3f `b_ub_fsp_jpn' "\\"
	noisily display " &(" %5.3f `se_lb_inc_jpn' ")&(" %5.3f `se_ub_inc_jpn' ")&(" %5.3f `se_lb_fsp_jpn' ")&(" %5.3f `se_ub_fsp_jpn'  ")\\"

	noisily display "\midrule\midrule"
	noisily display "\end{tabular}"
	noisily display "\begin{tablenotes}"
	noisily display "\footnotesize"
	noisily display "\item Standard errors are in parentheses. The bounds are calculated following Anagol and Fujiwara (2016)."
	noisily display "the Calonico, Cattaneo and Titiunik (2014) (CCT) optimal bandwidth."
	noisily display "\end{tablenotes}"
	noisily display "\end{threeparttable}"
	noisily display "\end{table}"
  
	log off
  
	log close
}


************
* Table E1 *
************

import delimited mnl_result.csv, clear
foreach dep in run win {
	foreach off in same higher {
		foreach x in ate se bw {
			sum `x' if depvar == "`dep'" & office == "`off'"
			local `x'_`dep'_`off' = r(mean)
		}
	}
}

quietly {

	capture log close
  
	log using tables/TableE1.tex, text replace

	
	
	noisily display "\begin{table}[htbp]"
	noisily display "\centering"
	noisily display "\begin{threeparttable}"
	noisily display "\caption{The Local MNL Estimates of First Rank Effects (Korea)}"
	noisily display "\label{table_mnl}"
	noisily display "\begin{tabular}{lccc}"
	noisily display "\midrule\midrule"
	noisily display "&\multicolumn{1}{c}{Run at \$t+1$}&\multicolumn{1}{c}{Win at \$t+1$}\\"
	noisily display "\cmidrule(r){2-2}\cmidrule(r){3-3}"
	noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}\\"
	noisily display "\midrule"
	noisily display "\addlinespace"
	noisily display " Same Office &" %5.3f `ate_run_same' "&" %5.3f `ate_win_same' "\\"
	noisily display " &(" %5.3f `se_run_same' ")&(" %5.3f `se_win_same'   ")\\"
	noisily display "\addlinespace"
	noisily display " Higher Office &" %5.3f `ate_run_higher' "&" %5.3f `ate_win_higher' "\\"
	noisily display " &(" %5.3f `se_run_higher' ")&(" %5.3f `se_win_higher'   ")\\"	
	noisily display "\midrule"
	noisily display "Bandwidth &" %5.3f `bw_run_higher' "&" %5.3f `bw_win_higher' "\\"
	noisily display "\midrule\midrule"
	noisily display "\end{tabular}"
	noisily display "\begin{tablenotes}"
	noisily display "\footnotesize"
	noisily display "\item Standard errors are in parenthesis. Estimation, standard error, and bandwidths are calculated according to 	noisily display Xu (2017)."
	noisily display "\end{tablenotes}"
	noisily display "\end{threeparttable}"
	noisily display "\end{table}"
	log off
  
	log close
}


************
* Table F1 *
************


eststo clear

foreach y in kor esp jpn {
	use data/data_`y', clear
	foreach x in frun fwin {
		capture rename num_seat num_win
		eststo snd_`x'_`y' : rdrobust `x' rv2 if num_win > 2
		quietly sum `x' if rv2 != . & num_win > 2
		local mean_`x'_`y' = r(mean)
		local sd_`x'_`y' = r(sd)
	}
}

use data/data_kor, clear
foreach x in frun fwin {
	eststo snd_high_`x'_kor : rdrobust `x'_high rv2 if num_win > 2
	quietly sum `x'_high if rv2 != . & num_win > 2
	local mean_high_`x' = r(mean)
	local sd_high_`x' = r(sd)
}

quietly {

	capture log close
  
	log using tables/TableF1.tex, text replace

	noisily display "\begin{table}[htbp]"
	noisily display "\centering"
	noisily display "\begin{threeparttable}"
	noisily display "\caption{The Rank Effect on Running in and Winning the Subsequent Election, Second vs. Third-Place Incmbents}"
	noisily display "\label{table_second}"
	noisily display "\begin{tabular}{lcccc}"
	noisily display "\midrule\midrule"
	noisily display "&\multicolumn{2}{c}{Same Office}&\multicolumn{2}{c}{Higher Office}\\"
	noisily display "\cmidrule(r){2-3}\cmidrule(r){4-5}"
	noisily display " & Estimate & Bandwidth & Estimate & Bandwidth\\"
	noisily display "\cmidrule(r){2-2}\cmidrule(r){3-3}\cmidrule(r){4-4}\cmidrule(r){5-5}"  
	noisily display "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}\\"
	noisily display "\midrule"
	noisily display "\multicolumn{5}{l}{\textit{Panel A: Korea}}\\"


	foreach x in frun fwin {
		
		foreach y in snd snd_high {
			estimates restore `y'_`x'_kor
			local obs_`y'     = e(N_h_l) + e(N_h_r)
			local bw_`y'      = e(h_l) + e(h_r)
			local beta_`y'    = e(tau_cl)
			local se_`y'      = e(se_tau_cl)
		}
		local varname : variable label `x'
		
		noisily display "\addlinespace"
		noisily display " `varname' & " %5.3f `beta_snd' "&" %5.3f `bw_snd' "&" %5.3f `beta_snd_high' "&" %5.3f `bw_snd_high' "\\"
		noisily display " &(" %5.3f `se_snd' ")&[N=" %6.0fc `obs_snd' "]&(" %5.3f `se_snd_high' ")&[N=" %6.0fc `obs_snd_high'  "]\\"
		noisily display " Dep. Var. Mean & " %5.3f `mean_`x'_kor' "&"  "&" %5.3f `mean_high_`x'' "&"  "\\"
		noisily display " Dep. Var. St. Dev. & " %5.3f `sd_`x'_kor' "&"  "&" %5.3f `sd_high_`x'' "&"  "\\"


	}

	noisily display "\addlinespace"
	noisily display "\addlinespace"
	noisily display "\multicolumn{5}{l}{\textit{Panel B: Spain}}\\"


	foreach x in frun fwin {
		
		foreach y in snd {
			estimates restore `y'_`x'_esp
			local obs_`y'     = e(N_h_l) + e(N_h_r)
			local bw_`y'      = e(h_l) + e(h_r)
			local beta_`y'    = e(tau_cl)
			local se_`y'      = e(se_tau_cl)
		}
		local varname : variable label `x'
		
		noisily display "\addlinespace"
		noisily display " `varname' & " %5.3f `beta_snd' "&" %5.3f `bw_snd' "&&\\"
		noisily display " &(" %5.3f `se_snd' ")&[N=" %6.0fc `obs_snd' "]" "&&\\"
		noisily display " Dep. Var. Mean & " %5.3f `mean_`x'_esp' "&"  "&"  "&"  "\\"
		noisily display " Dep. Var. St. Dev. & " %5.3f `sd_`x'_esp' "&"  "&"  "&"  "\\"


	}	
	
	noisily display "\addlinespace"
	noisily display "\addlinespace"
	noisily display "\multicolumn{5}{l}{\textit{Panel C: Japan}}\\"


	foreach x in frun fwin {
		
		foreach y in snd {
			estimates restore `y'_`x'_jpn
			local obs_`y'     = e(N_h_l) + e(N_h_r)
			local bw_`y'      = e(h_l) + e(h_r)
			local beta_`y'    = e(tau_cl)
			local se_`y'      = e(se_tau_cl)
		}
		local varname : variable label `x'
		
		noisily display "\addlinespace"
		noisily display " `varname' & " %5.3f `beta_snd' "&" %5.3f `bw_snd' "&&\\"
		noisily display " &(" %5.3f `se_snd' ")&[N=" %6.0fc `obs_snd' "]" "&&\\"
		noisily display " Dep. Var. Mean & " %5.3f `mean_`x'_jpn' "&"  "&"  "&"  "\\"
		noisily display " Dep. Var. St. Dev. & " %5.3f `sd_`x'_jpn' "&"  "&"  "&"  "\\"

	}	

	noisily display "\midrule\midrule"
	noisily display "\end{tabular}"
	noisily display "\begin{tablenotes}"
	noisily display "\footnotesize"
	noisily display "\item Standard errors in parentheses are calculated according to Calonico, Cattaneo and Titiunik (2014). The number of observations are in brackets."
	noisily display "Estimates are from local linear regressions with triangular kernel using"
	noisily display "the Calonico, Cattaneo and Titiunik (2014) (CCT) optimal bandwidth."
	noisily display "\end{tablenotes}"
	noisily display "\end{threeparttable}"
	noisily display "\end{table}"
  
	log off
  
	log close
}
